SystemOrganization addCategory: #'MC2-Issues-Core'!
SystemOrganization addCategory: #'MC2-Issues-Domain'!

!MDElementHandler methodsFor: '*mc2-issues' stamp: 'jf 1/31/2010 11:51'!
handleIssue: anIssueElement 
	^ self handleElement: anIssueElement! !

MDElementHandler subclass: #MDIssueAdaptionHandler
	instanceVariableNames: 'database'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Issues-Domain'!

!MDIssueAdaptionHandler class methodsFor: 'instance creation' stamp: 'jf 1/31/2010 11:48'!
database: anIssueDatabase
	^ self basicNew initializeWithDatabase: anIssueDatabase; yourself! !

!MDIssueAdaptionHandler class methodsFor: 'instance creation' stamp: 'jf 1/31/2010 11:47'!
new
	^ self database: MDIssueDatabase default! !

!MDIssueAdaptionHandler methodsFor: 'handling' stamp: 'jf 1/31/2010 16:54'!
handleIssue: anIssueElement
	^ MDIssueAdaptor forElement: anIssueElement inDatabase: database! !

!MDIssueAdaptionHandler methodsFor: 'initialization' stamp: 'jf 1/31/2010 11:47'!
initializeWithDatabase: anIssueDatabase
	self initialize.
	database := anIssueDatabase! !

MDAdaptor subclass: #MDIssueAdaptor
	instanceVariableNames: 'database'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Issues-Domain'!

!MDIssueAdaptor class methodsFor: 'instance creation' stamp: 'jf 1/31/2010 16:13'!
forElement: anElement
	self shouldNotImplement! !

!MDIssueAdaptor class methodsFor: 'instance creation' stamp: 'jf 1/31/2010 16:12'!
forElement: anElement inDatabase: anIssueDatabase
	^ self basicNew
		initializeWithElement: anElement database: anIssueDatabase;
		yourself! !

!MDIssueAdaptor methodsFor: 'accessing' stamp: 'jf 1/31/2010 15:52'!
database
	^ database! !

!MDIssueAdaptor methodsFor: 'initialization' stamp: 'jf 1/31/2010 15:53'!
initializeWithElement: anElement database: anIssueDatabase
	self initializeWithElement: anElement.
	database := anIssueDatabase! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:15'!
isLoadable: properties
	^ true! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:17'!
isPresent
	^ database issues anySatisfy: [:each | each id = element id]! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:50'!
isUpToDate: properties
	| issue |
	issue := self issueIfAbsent: [^ properties].
	^ (issue title = properties title) and: [
		(issue status = properties status) and: [
		(issue description = properties description) ] ]! !

!MDIssueAdaptor methodsFor: 'private' stamp: 'jf 1/31/2010 16:30'!
issueIfAbsent: absentBlock
	^ database issues detect: [:each | each id = element id] ifNone: absentBlock! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:46'!
load: properties
	self isPresent ifFalse: [database add: (MDIssue withId: element id)].
	(self issueIfAbsent: [self error: 'Issue is missing'])
		title: properties title;
		status: properties status;
		description: properties description! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:31'!
remove
	database remove: (self issueIfAbsent: [^ self])! !

!MDIssueAdaptor methodsFor: 'public' stamp: 'jf 1/31/2010 16:48'!
update: properties
	| issue |
	issue := self issueIfAbsent: [^ properties].
	properties
		title: issue title;
		status: issue status;
		description: issue description.
	^ properties! !

GRObject subclass: #MDIssue
	instanceVariableNames: 'title description status id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Issues-Core'!

!MDIssue class methodsFor: 'instance creation' stamp: 'jf 1/25/2010 20:08'!
new
	^ self withId: UUID new! !

!MDIssue class methodsFor: 'instance creation' stamp: 'jf 1/25/2010 20:08'!
withId: aUUID
	^ self basicNew initializeWithId: aUUID; yourself! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
description
	^ description! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
description: anObject
	description := anObject! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/25/2010 20:04'!
id
	^ id! !

!MDIssue methodsFor: 'initialization' stamp: 'jf 1/25/2010 20:07'!
initializeWithId: aUUID
	self initialize.
	id := aUUID.
	status := #new! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
status
	^ status! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
status: anObject
	status := anObject! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
title
	^ title! !

!MDIssue methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:15'!
title: anObject
	title := anObject! !

GRObject subclass: #MDIssueDatabase
	instanceVariableNames: 'issues'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'MC2-Issues-Core'!

!MDIssueDatabase class methodsFor: 'accessing' stamp: 'jf 1/31/2010 11:42'!
default
	^ Default ifNil: [Default := self new]! !

!MDIssueDatabase class methodsFor: 'initialize-release' stamp: 'jf 1/25/2010 20:10'!
unload
	Default := nil! !

!MDIssueDatabase methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:47'!
add: anIssue
	^ issues add: anIssue! !

!MDIssueDatabase methodsFor: 'initialization' stamp: 'jf 1/31/2010 11:42'!
initialize
	super initialize.
	issues := OrderedCollection new! !

!MDIssueDatabase methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:46'!
issues
	^ issues! !

!MDIssueDatabase methodsFor: 'accessing' stamp: 'jf 1/19/2010 20:47'!
remove: anIssue
	^ issues remove: anIssue! !

MDElement subclass: #MDIssueElement
	instanceVariableNames: 'id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Issues-Domain'!

!MDIssueElement class methodsFor: 'instance creation' stamp: 'jf 1/25/2010 20:17'!
id: aUUID
	^ self basicNew
		initializeWithId: aUUID;
		yourself! !

!MDIssueElement class methodsFor: 'instance creation' stamp: 'jf 1/25/2010 20:17'!
new
	self shouldNotImplement! !

!MDIssueElement methodsFor: 'dispatching' stamp: 'jf 1/19/2010 21:49'!
handleWith: anObject
	^ anObject handleIssue: self! !

!MDIssueElement methodsFor: 'accessing' stamp: 'jf 1/31/2010 16:18'!
id
	^ id! !

!MDIssueElement methodsFor: 'initialization' stamp: 'jf 1/25/2010 20:14'!
initializeWithId: aUUID
	self initialize.
	id := aUUID! !

MDDomain subclass: #MDIssuesDomain
	instanceVariableNames: 'database'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Issues-Domain'!

!MDIssuesDomain class methodsFor: 'as yet unclassified' stamp: 'cwp 6/6/2010 16:01'!
type
	^ #issues! !

!MDIssuesDomain methodsFor: 'public' stamp: 'jf 1/31/2010 11:48'!
adapt: anElement
	^ anElement handleWith: (MDIssueAdaptionHandler database: database)! !

!MDIssuesDomain methodsFor: 'testing' stamp: 'jf 1/19/2010 21:22'!
name
	^ #issues! !
